=== modified file 'drizzled/field/blob.cc'
--- drizzled/field/blob.cc	2009-06-23 21:20:32 +0000
+++ drizzled/field/blob.cc	2009-06-24 18:16:14 +0000
@@ -32,8 +32,8 @@
 uint32_t
 blob_pack_length_to_max_length(uint32_t arg)
 {
-  return (uint32_t)cmax(UINT32_MAX,
-                        (INT64_C(1) << min(arg, 4U) * 8) - INT64_C(1));
+  return max(UINT32_MAX,
+             (uint32_t)((INT64_C(1) << min(arg, 4U) * 8) - INT64_C(1)));
 }
 
 

=== modified file 'drizzled/field/double.cc'
--- drizzled/field/double.cc	2009-03-08 23:45:12 +0000
+++ drizzled/field/double.cc	2009-06-24 18:16:14 +0000
@@ -26,6 +26,10 @@
 #include <drizzled/session.h>
 #include <drizzled/protocol.h>
 
+#include <algorithm>
+
+using namespace std;
+
 
 /****************************************************************************
   double precision floating point numbers
@@ -135,7 +139,7 @@
 #endif
     doubleget(nr,ptr);
 
-  uint32_t to_length=cmax(field_length, (uint32_t)DOUBLE_TO_STRING_CONVERSION_BUFFER_SIZE);
+  uint32_t to_length= max(field_length, (uint32_t)DOUBLE_TO_STRING_CONVERSION_BUFFER_SIZE);
   val_buffer->alloc(to_length);
   char *to=(char*) val_buffer->ptr();
   size_t len;

=== modified file 'drizzled/field/int64_t.cc'
--- drizzled/field/int64_t.cc	2009-03-08 23:45:12 +0000
+++ drizzled/field/int64_t.cc	2009-06-24 18:16:14 +0000
@@ -25,6 +25,10 @@
 #include <drizzled/table.h>
 #include <drizzled/session.h>
 
+#include <algorithm>
+
+using namespace std;
+
 
 /****************************************************************************
  Field type int64_t int (8 bytes)
@@ -144,7 +148,7 @@
 {
   const CHARSET_INFO * const cs= &my_charset_bin;
   uint32_t length;
-  uint32_t mlength=cmax(field_length+1,22*cs->mbmaxlen);
+  uint32_t mlength= max(field_length+1,22*cs->mbmaxlen);
   val_buffer->alloc(mlength);
   char *to=(char*) val_buffer->ptr();
   int64_t j;

=== modified file 'drizzled/field/long.cc'
--- drizzled/field/long.cc	2009-03-08 23:45:12 +0000
+++ drizzled/field/long.cc	2009-06-24 18:16:14 +0000
@@ -25,6 +25,11 @@
 #include <drizzled/table.h>
 #include <drizzled/session.h>
 
+#include <algorithm>
+
+using namespace std;
+
+
 /****************************************************************************
 ** long int
 ****************************************************************************/
@@ -149,7 +154,7 @@
 {
   const CHARSET_INFO * const cs= &my_charset_bin;
   uint32_t length;
-  uint32_t mlength=cmax(field_length+1,12*cs->mbmaxlen);
+  uint32_t mlength= max(field_length+1,12*cs->mbmaxlen);
   val_buffer->alloc(mlength);
   char *to=(char*) val_buffer->ptr();
   int32_t j;

=== modified file 'drizzled/function/additive_op.cc'
--- drizzled/function/additive_op.cc	2009-06-23 21:37:44 +0000
+++ drizzled/function/additive_op.cc	2009-06-24 18:16:14 +0000
@@ -30,9 +30,9 @@
 */
 void Item_func_additive_op::result_precision()
 {
-  decimals= cmax(args[0]->decimals, args[1]->decimals);
-  int max_int_part= cmax(args[0]->decimal_precision() - args[0]->decimals,
-                         args[1]->decimal_precision() - args[1]->decimals);
+  decimals= max(args[0]->decimals, args[1]->decimals);
+  int max_int_part= max(args[0]->decimal_precision() - args[0]->decimals,
+                        args[1]->decimal_precision() - args[1]->decimals);
   int precision= min(max_int_part + 1 + decimals, DECIMAL_MAX_PRECISION);
 
   /* Integer operations keep unsigned_flag if one of arguments is unsigned */

=== modified file 'drizzled/function/math/divide.cc'
--- drizzled/function/math/divide.cc	2009-06-23 21:37:44 +0000
+++ drizzled/function/math/divide.cc	2009-06-24 18:16:14 +0000
@@ -86,13 +86,15 @@
 {
   prec_increment= current_session->variables.div_precincrement;
   Item_num_op::fix_length_and_dec();
-  switch(hybrid_type) {
+
+  switch(hybrid_type)
+  {
   case REAL_RESULT:
   {
-    decimals=cmax(args[0]->decimals,args[1]->decimals)+prec_increment;
+    decimals= max(args[0]->decimals,args[1]->decimals)+prec_increment;
     set_if_smaller(decimals, NOT_FIXED_DEC);
-    max_length=args[0]->max_length - args[0]->decimals + decimals;
-    uint32_t tmp=float_length(decimals);
+    max_length= args[0]->max_length - args[0]->decimals + decimals;
+    uint32_t tmp= float_length(decimals);
     set_if_smaller(max_length,tmp);
     break;
   }

=== modified file 'drizzled/function/math/mod.cc'
--- drizzled/function/math/mod.cc	2009-03-08 23:45:12 +0000
+++ drizzled/function/math/mod.cc	2009-06-24 18:16:14 +0000
@@ -20,6 +20,10 @@
 #include <drizzled/server_includes.h>
 #include <drizzled/function/math/mod.h>
 
+#include <algorithm>
+
+using namespace std;
+
 int64_t Item_func_mod::int_op()
 {
   assert(fixed == 1);
@@ -88,8 +92,8 @@
 
 void Item_func_mod::result_precision()
 {
-  decimals= cmax(args[0]->decimals, args[1]->decimals);
-  max_length= cmax(args[0]->max_length, args[1]->max_length);
+  decimals= max(args[0]->decimals, args[1]->decimals);
+  max_length= max(args[0]->max_length, args[1]->max_length);
 }
 
 

=== modified file 'drizzled/function/str/concat.cc'
--- drizzled/function/str/concat.cc	2008-12-12 20:40:37 +0000
+++ drizzled/function/str/concat.cc	2009-06-24 18:16:14 +0000
@@ -23,6 +23,10 @@
 #include <drizzled/error.h>
 #include <drizzled/session.h>
 
+#include <algorithm>
+
+using namespace std;
+
 String *Item_func_concat::val_str(String *str)
 {
   assert(fixed == 1);
@@ -125,7 +129,7 @@
           }
           else
           {
-            uint32_t new_len = cmax(tmp_value.alloced_length() * 2, concat_len);
+            uint32_t new_len= max(tmp_value.alloced_length() * 2, concat_len);
 
             if (tmp_value.realloc(new_len))
               goto null;
@@ -295,7 +299,7 @@
         }
         else
         {
-          uint32_t new_len = cmax(tmp_value.alloced_length() * 2, concat_len);
+          uint32_t new_len= max(tmp_value.alloced_length() * 2, concat_len);
 
           if (tmp_value.realloc(new_len))
             goto null;

=== modified file 'drizzled/function/str/export_set.cc'
--- drizzled/function/str/export_set.cc	2009-06-23 21:37:44 +0000
+++ drizzled/function/str/export_set.cc	2009-06-24 18:16:14 +0000
@@ -95,7 +95,7 @@
 
 void Item_func_export_set::fix_length_and_dec()
 {
-  uint32_t length= cmax(args[1]->max_length,args[2]->max_length);
+  uint32_t length= max(args[1]->max_length,args[2]->max_length);
   uint32_t sep_length= (arg_count > 3 ? args[3]->max_length : 1);
   max_length= length*64+sep_length*63;
 

=== modified file 'drizzled/function/str/weight_string.cc'
--- drizzled/function/str/weight_string.cc	2008-12-12 20:40:37 +0000
+++ drizzled/function/str/weight_string.cc	2009-06-24 18:16:14 +0000
@@ -21,12 +21,16 @@
 #include CSTDINT_H
 #include <drizzled/function/str/weight_string.h>
 
+#include <algorithm>
+
+using namespace std;
+
 void Item_func_weight_string::fix_length_and_dec()
 {
   const CHARSET_INFO * const cs= args[0]->collation.collation;
   collation.set(&my_charset_bin, args[0]->collation.derivation);
   flags= my_strxfrm_flag_normalize(flags, cs->levels_for_order);
-  max_length= cs->mbmaxlen * cmax(args[0]->max_length, nweights);
+  max_length= cs->mbmaxlen * max(args[0]->max_length, nweights);
   maybe_null= 1;
 }
 
@@ -43,7 +47,7 @@
     goto nl;
 
   tmp_length= cs->coll->strnxfrmlen(cs, cs->mbmaxlen *
-                                        cmax(res->length(), nweights));
+                                        max(res->length(), nweights));
 
   if (tmp_value.alloc(tmp_length))
     goto nl;

